.. _api-service:

Job.Service API
***************

The Service class allows databases and servers to be spawned within a Toil workflow.

.. autoclass:: toil.job::Job.Service
   :members:
   :noindex:
